@@ -131,7 +131,8 @@ class NPM(Command):
         log.info("Installing build dependencies with npm. This may take a while...")
         run(['npm', 'install'], cwd=here)
         run(['npm', 'run', 'clean'], cwd=here)
-        run(['npm', 'run', 'build:all'], cwd=here)
+        run(['npm', 'run', 'install'], cwd=here)
+        run(['npm', 'run', 'build'], cwd=here)
 
         for t in self.targets:
             if not os.path.exists(t):
